#
# This is a template package spec that will support Go builds following the OpenShift conventions.
# It expects a set of standard env vars that define the Git version being built and can also handle
# multi-architecture Linux builds. It has stubs for cross building.
#
# Search for TODO and fill those sections out as appropriate.
#

#debuginfo not supported with Go
%global debug_package %{nil}

# modifying the Go binaries breaks the DWARF debugging
%global __os_install_post %{_rpmconfigdir}/brp-compress

# %commit and %os_git_vars are intended to be set by tito custom builders provided
# in the .tito/lib directory. The values in this spec file will not be kept up to date.
%{!?commit: %global commit 22be164a90dc8d2705ce05638e6ce61839596dfc }
%global shortcommit %(c=%{commit}; echo ${c:0:7})
# os_git_vars needed to run hack scripts during rpm builds
%global os_git_vars OS_GIT_VERSION=3.11.570-1.g22be164-22be164 OS_GIT_MAJOR=3 OS_GIT_MINOR=11 OS_GIT_PATCH=570 OS_GIT_COMMIT=22be164a90dc8d2705ce05638e6ce61839596dfc OS_GIT_TREE_STATE=clean

%if 0%{?skip_build}
%global do_build 0
%else
%global do_build 1
%endif
%if 0%{?skip_prep}
%global do_prep 0
%else
%global do_prep 1
%endif

%if 0%{?fedora} || 0%{?epel}
%global need_redistributable_set 0
%else
# Due to library availability, redistributable builds only work on x86_64
%ifarch x86_64
%global need_redistributable_set 1
%else
%global need_redistributable_set 0
%endif
%endif
%{!?make_redistributable: %global make_redistributable %{need_redistributable_set}}

#
# Customize from here.
#

%global golang_version 1.9.1
%{!?version: %global version 0.0.1}
%{!?release: %global release 1}
%global package_name openshift-cluster-capacity
%global product_name OpenShift Cluster Capacity
%global import_path github.com/openshift/cluster-capacity

Name:           openshift-enterprise-cluster-capacity
Version:        3.11.570
Release:        1.g22be164%{?dist}
Summary:        TODO
License:        ASL 2.0
URL:            https://%{import_path}

Source0:        openshift-enterprise-cluster-capacity-3.11.570-1.g22be164.tar.gz
BuildRequires:  golang >= %{golang_version}

# If go_arches not defined fall through to implicit golang archs
%if 0%{?go_arches:1}
ExclusiveArch:  %{go_arches}
%else
ExclusiveArch:  x86_64 aarch64 ppc64le s390x
%endif

### AUTO-BUNDLED-GEN-ENTRY-POINT

%description
[Maintainer] product: OpenShift Container Platform, component: kube-scheduler
The Cluster Capacity tool assists in calculating used capacity on a
Kubernetes cluster.

%prep
%if 0%{do_prep}
%setup -q -n openshift-enterprise-cluster-capacity-3.11.570
%endif

%build
%if 0%{do_build}
%if 0%{make_redistributable}
# Create Binaries for all internally defined arches
%{os_git_vars} make build-cross
%else
# Create Binaries only for building arch
%ifarch x86_64
  BUILD_PLATFORM="linux/amd64"
%endif
%ifarch %{ix86}
  BUILD_PLATFORM="linux/386"
%endif
%ifarch ppc64le
  BUILD_PLATFORM="linux/ppc64le"
%endif
%ifarch %{arm} aarch64
  BUILD_PLATFORM="linux/arm64"
%endif
%ifarch s390x
  BUILD_PLATFORM="linux/s390x"
%endif
OS_ONLY_BUILD_PLATFORMS="${BUILD_PLATFORM}" %{os_git_vars} make build-cross
%endif
%endif

%install

PLATFORM="$(go env GOHOSTOS)/$(go env GOHOSTARCH)"
install -d %{buildroot}%{_bindir}

# Install linux components
for bin in hypercc
do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 _output/local/bin/${PLATFORM}/${bin} %{buildroot}%{_bindir}/${bin}
done

# EXAMPLE: Install tests
# install -d %{buildroot}%{_libexecdir}/%{name}
# install -p -m 755 _output/local/bin/${PLATFORM}/extended.test %{buildroot}%{_libexecdir}/%{name}/

# EXAMPLE: Install other files
# install -p -m 0755 _output/local/bin/${PLATFORM}/sdn-cni-plugin %{buildroot}/opt/cni/bin/openshift-sdn

%files
%doc README.md
%license LICENSE
%{_bindir}/hypercc

%pre

%changelog
* Mon Nov 06 2017 Anonymous <anon@nowhere.com> 0.0.1
- Initial example of spec.
